@@ -5,6 +5,7 @@ use warnings;
 use Carp;
 
 use base 'Dancer::Object::Singleton';
+use Dancer::Exception qw(:all);
 
 __PACKAGE__->attributes(qw/ hooks registered_hooks/);
 
@@ -19,12 +20,12 @@ sub install_hooks {
     my ( $self, @hooks_name ) = @_;
 
     if ( !scalar @hooks_name ) {
-        croak "at least one name is required";
+        raise core_factory_hook => "at least one name is required";
     }
 
     foreach my $hook_name (@hooks_name) {
         if ( $self->hook_is_registered($hook_name) ) {
-            croak "$hook_name is already regsitered, please use another name";
+            raise core_factory_hook => "$hook_name is already regsitered, please use another name";
         }
         $self->_add_hook( $hook_name );
     }
@@ -53,10 +54,10 @@ sub hook_is_registered {
 sub execute_hooks {
     my ($self, $hook_name, @args) = @_;
 
-    croak("Can't ask for hooks without a position") unless $hook_name;
+    raise core_factory_hook => "Can't ask for hooks without a position" unless $hook_name;
 
     if (!$self->hook_is_registered($hook_name)){
-        croak("The hook '$hook_name' doesn't exists");
+        raise core_factory_hook => "The hook '$hook_name' doesn't exists";
     }
 
    foreach my $h (@{$self->get_hooks_for($hook_name)}) {
@@ -67,7 +68,7 @@ sub execute_hooks {
 sub get_hooks_for {
     my ( $self, $hook_name ) = @_;
 
-    croak("Can't ask for hooks without a position") unless $hook_name;
+    raise core_factory_hook => "Can't ask for hooks without a position" unless $hook_name;
 
     $self->hooks->{$hook_name} || [];
 }
